/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.blogger.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for User.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Blogger API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class User extends GenericJson {

  /**
   * Profile summary information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String about;

  /**
   * The container of blogs for this user.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Blogs blogs;

  /**
   * The timestamp of when this profile was created, in seconds since epoch.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * The display name.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String displayName;

  /**
   * The identifier for this User.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of this entity. Always blogger#user
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * This user's locale
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Locale locale;

  /**
   * The API REST URL to fetch this resource from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The user's profile page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String url;

  /**
   * Profile summary information.
   * The value returned may be {@code null}.
   */
  public String getAbout() {
    return about;
  }

  /**
   * Profile summary information.
   * The value set may be {@code null}.
   */
  public User setAbout(String about) {
    this.about = about;
    return this;
  }

  /**
   * The container of blogs for this user.
   * The value returned may be {@code null}.
   */
  public Blogs getBlogs() {
    return blogs;
  }

  /**
   * The container of blogs for this user.
   * The value set may be {@code null}.
   */
  public User setBlogs(Blogs blogs) {
    this.blogs = blogs;
    return this;
  }

  /**
   * The timestamp of when this profile was created, in seconds since epoch.
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * The timestamp of when this profile was created, in seconds since epoch.
   * The value set may be {@code null}.
   */
  public User setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * The display name.
   * The value returned may be {@code null}.
   */
  public String getDisplayName() {
    return displayName;
  }

  /**
   * The display name.
   * The value set may be {@code null}.
   */
  public User setDisplayName(String displayName) {
    this.displayName = displayName;
    return this;
  }

  /**
   * The identifier for this User.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The identifier for this User.
   * The value set may be {@code null}.
   */
  public User setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of this entity. Always blogger#user
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of this entity. Always blogger#user
   * The value set may be {@code null}.
   */
  public User setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * This user's locale
   * The value returned may be {@code null}.
   */
  public Locale getLocale() {
    return locale;
  }

  /**
   * This user's locale
   * The value set may be {@code null}.
   */
  public User setLocale(Locale locale) {
    this.locale = locale;
    return this;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The API REST URL to fetch this resource from.
   * The value set may be {@code null}.
   */
  public User setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * The user's profile page.
   * The value returned may be {@code null}.
   */
  public String getUrl() {
    return url;
  }

  /**
   * The user's profile page.
   * The value set may be {@code null}.
   */
  public User setUrl(String url) {
    this.url = url;
    return this;
  }

  /**
   * The container of blogs for this user.
   */
  public static final class Blogs extends GenericJson {

    /**
     * The URL of the Blogs for this user.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String selfLink;

    /**
     * The URL of the Blogs for this user.
     * The value returned may be {@code null}.
     */
    public String getSelfLink() {
      return selfLink;
    }

    /**
     * The URL of the Blogs for this user.
     * The value set may be {@code null}.
     */
    public Blogs setSelfLink(String selfLink) {
      this.selfLink = selfLink;
      return this;
    }

  }

  /**
   * This user's locale
   */
  public static final class Locale extends GenericJson {

    /**
     * The user's country setting.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String country;

    /**
     * The user's language setting.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String language;

    /**
     * The user's language variant setting.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String variant;

    /**
     * The user's country setting.
     * The value returned may be {@code null}.
     */
    public String getCountry() {
      return country;
    }

    /**
     * The user's country setting.
     * The value set may be {@code null}.
     */
    public Locale setCountry(String country) {
      this.country = country;
      return this;
    }

    /**
     * The user's language setting.
     * The value returned may be {@code null}.
     */
    public String getLanguage() {
      return language;
    }

    /**
     * The user's language setting.
     * The value set may be {@code null}.
     */
    public Locale setLanguage(String language) {
      this.language = language;
      return this;
    }

    /**
     * The user's language variant setting.
     * The value returned may be {@code null}.
     */
    public String getVariant() {
      return variant;
    }

    /**
     * The user's language variant setting.
     * The value set may be {@code null}.
     */
    public Locale setVariant(String variant) {
      this.variant = variant;
      return this;
    }

  }

}
